# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.dns.v1 import dns_zone_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2
from yandex.cloud.dns.v1 import dns_zone_service_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DnsZoneServiceStub(object):
    """A set of methods for managing DNS zones.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/Get',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.DnsZone.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/List',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/Create',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.CreateDnsZoneRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/Update',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateDnsZoneRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/Delete',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.DeleteDnsZoneRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetRecordSet = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/GetRecordSet',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRecordSetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.RecordSet.FromString,
                )
        self.ListRecordSets = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/ListRecordSets',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsResponse.FromString,
                )
        self.UpdateRecordSets = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/UpdateRecordSets',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateRecordSetsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpsertRecordSets = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/UpsertRecordSets',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpsertRecordSetsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.dns.v1.DnsZoneService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class DnsZoneServiceServicer(object):
    """A set of methods for managing DNS zones.
    """

    def Get(self, request, context):
        """Returns the specified DNS zone.

        To get the list of all available DNS zones, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of DNS zones in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a DNS zone in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified DNS zone.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified DNS zone. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecordSet(self, request, context):
        """Returns the specified record set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRecordSets(self, request, context):
        """Retrieves the list of record sets in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRecordSets(self, request, context):
        """Method with strict control for changing zone state. Returns error when:
        1. Deleted record is not found.
        2. Found record with matched type and name but different TTL or value.
        3. Attempted to add record with existing name and type.
        Deletions happen first. If a record with the same name and type exists in both lists,
        then the existing record will be deleted, and a new one added.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertRecordSets(self, request, context):
        """Method without strict control for changing zone state. Nothing happens if deleted record doesn't exist.
        Deletes records that match all specified fields which allows to delete only specified records from a record set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified DNS zone.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified DNS zone.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified DNS zone.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified DNS zone.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DnsZoneServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.DnsZone.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.CreateDnsZoneRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateDnsZoneRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.DeleteDnsZoneRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetRecordSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecordSet,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRecordSetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.RecordSet.SerializeToString,
            ),
            'ListRecordSets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecordSets,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsResponse.SerializeToString,
            ),
            'UpdateRecordSets': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRecordSets,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateRecordSetsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpsertRecordSets': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertRecordSets,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpsertRecordSetsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.dns.v1.DnsZoneService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DnsZoneService(object):
    """A set of methods for managing DNS zones.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/Get',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRequest.SerializeToString,
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.DnsZone.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/List',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesRequest.SerializeToString,
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZonesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/Create',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.CreateDnsZoneRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/Update',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateDnsZoneRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/Delete',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.DeleteDnsZoneRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecordSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/GetRecordSet',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.GetDnsZoneRecordSetRequest.SerializeToString,
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.RecordSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRecordSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/ListRecordSets',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsRequest.SerializeToString,
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneRecordSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRecordSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/UpdateRecordSets',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpdateRecordSetsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertRecordSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/UpsertRecordSets',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.UpsertRecordSetsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/ListOperations',
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__service__pb2.ListDnsZoneOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dns.v1.DnsZoneService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.containers.v1 import container_pb2 as yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2
from yandex.cloud.serverless.containers.v1 import container_service_pb2 as yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2


class ContainerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/Get',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Container.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/List',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/Create',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.CreateContainerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/Update',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.UpdateContainerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/Delete',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeleteContainerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeployRevision = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/DeployRevision',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeployContainerRevisionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Rollback = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/Rollback',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.RollbackContainerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetRevision = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/GetRevision',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRevisionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Revision.FromString,
                )
        self.ListRevisions = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/ListRevisions',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsResponse.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.containers.v1.ContainerService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class ContainerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployRevision(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rollback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRevision(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRevisions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContainerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Container.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.CreateContainerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.UpdateContainerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeleteContainerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeployRevision': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployRevision,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeployContainerRevisionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Rollback': grpc.unary_unary_rpc_method_handler(
                    servicer.Rollback,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.RollbackContainerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetRevision': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRevision,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRevisionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Revision.SerializeToString,
            ),
            'ListRevisions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRevisions,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.containers.v1.ContainerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ContainerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/Get',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Container.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/List',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/Create',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.CreateContainerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/Update',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.UpdateContainerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/Delete',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeleteContainerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployRevision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/DeployRevision',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.DeployContainerRevisionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Rollback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/Rollback',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.RollbackContainerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRevision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/GetRevision',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.GetContainerRevisionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.Revision.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRevisions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/ListRevisions',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainersRevisionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/ListOperations',
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__service__pb2.ListContainerOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.containers.v1.ContainerService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/operation/operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/operation/operation.proto',
  package='yandex.cloud.operation',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operation',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&yandex/cloud/operation/operation.proto\x12\x16yandex.cloud.operation\x1a\x19google/protobuf/any.proto\x1a\x17google/rpc/status.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb0\x02\n\tOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64one\x18\x06 \x01(\x08\x12&\n\x08metadata\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\x12#\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12(\n\x08response\x18\t \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06resultBb\n\x1ayandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operationb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='yandex.cloud.operation.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.operation.Operation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.operation.Operation.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.operation.Operation.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='yandex.cloud.operation.Operation.created_by', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at', full_name='yandex.cloud.operation.Operation.modified_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='yandex.cloud.operation.Operation.done', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.operation.Operation.metadata', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='yandex.cloud.operation.Operation.error', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='yandex.cloud.operation.Operation.response', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='yandex.cloud.operation.Operation.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=152,
  serialized_end=456,
)

_OPERATION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATION.fields_by_name['modified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATION.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.fields_by_name['error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OPERATION.fields_by_name['response'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OPERATION.oneofs_by_name['result'].fields.append(
  _OPERATION.fields_by_name['error'])
_OPERATION.fields_by_name['error'].containing_oneof = _OPERATION.oneofs_by_name['result']
_OPERATION.oneofs_by_name['result'].fields.append(
  _OPERATION.fields_by_name['response'])
_OPERATION.fields_by_name['response'].containing_oneof = _OPERATION.oneofs_by_name['result']
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'yandex.cloud.operation.operation_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.operation.Operation)
  })
_sym_db.RegisterMessage(Operation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/database_service.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/mdb/clickhouse/v1/database_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/mdb/clickhouse/v1/database.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x15ListDatabasesResponse\x12;\n\tdatabases\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12I\n\rdatabase_spec\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\xb4\x06\n\x0f\x44\x61tabaseService\x12\xb3\x01\n\x03Get\x12\x32.yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest\x1a(.yandex.cloud.mdb.clickhouse.v1.Database\"N\x82\xd3\xe4\x93\x02H\x12\x46/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}\x12\xb3\x01\n\x04List\x12\x34.yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest\x1a\x35.yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/managed-clickhouse/v1/clusters/{cluster_id}/databases\x12\xcb\x01\n\x06\x43reate\x12\x35.yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02;\"6/managed-clickhouse/v1/clusters/{cluster_id}/databases:\x01*\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xe6\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02H*F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.EmptyBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2.DESCRIPTOR,])




_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=380,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=500,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=611,
)


_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_spec', full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest.database_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=746,
)


_CREATEDATABASEMETADATA = _descriptor.Descriptor(
  name='CreateDatabaseMetadata',
  full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.clickhouse.v1.CreateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=815,
)


_DELETEDATABASEREQUEST = _descriptor.Descriptor(
  name='DeleteDatabaseRequest',
  full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=929,
)


_DELETEDATABASEMETADATA = _descriptor.Descriptor(
  name='DeleteDatabaseMetadata',
  full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=998,
)

_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2._DATABASE
_CREATEDATABASEREQUEST.fields_by_name['database_spec'].message_type = yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2._DATABASESPEC
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseMetadata'] = _CREATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['DeleteDatabaseRequest'] = _DELETEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatabaseMetadata'] = _DELETEDATABASEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)

CreateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('CreateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.CreateDatabaseMetadata)
  })
_sym_db.RegisterMessage(CreateDatabaseMetadata)

DeleteDatabaseRequest = _reflection.GeneratedProtocolMessageType('DeleteDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseRequest)
  })
_sym_db.RegisterMessage(DeleteDatabaseRequest)

DeleteDatabaseMetadata = _reflection.GeneratedProtocolMessageType('DeleteDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.DeleteDatabaseMetadata)
  })
_sym_db.RegisterMessage(DeleteDatabaseMetadata)


DESCRIPTOR._options = None
_GETDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_GETDATABASEREQUEST.fields_by_name['database_name']._options = None
_LISTDATABASESREQUEST.fields_by_name['cluster_id']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
_CREATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_CREATEDATABASEREQUEST.fields_by_name['database_spec']._options = None
_DELETEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_DELETEDATABASEREQUEST.fields_by_name['database_name']._options = None

_DATABASESERVICE = _descriptor.ServiceDescriptor(
  name='DatabaseService',
  full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1001,
  serialized_end=1821,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2._DATABASE,
    serialized_options=b'\202\323\344\223\002H\022F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDATABASESREQUEST,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/managed-clickhouse/v1/clusters/{cluster_id}/databases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;\"6/managed-clickhouse/v1/clusters/{cluster_id}/databases:\001*\262\322*\"\n\026CreateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H*F/managed-clickhouse/v1/clusters/{cluster_id}/databases/{database_name}\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASESERVICE)

DESCRIPTOR.services_by_name['DatabaseService'] = _DATABASESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/api_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import api_key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/api_key_service.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/iam/v1/api_key_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a!yandex/cloud/iam/v1/api_key.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x10GetApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"x\n\x12ListApiKeysRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"]\n\x13ListApiKeysResponse\x12-\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.iam.v1.ApiKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"[\n\x13\x43reateApiKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"T\n\x14\x43reateApiKeyResponse\x12,\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32\x1b.yandex.cloud.iam.v1.ApiKey\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x88\x01\n\x13UpdateApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"*\n\x14UpdateApiKeyMetadata\x12\x12\n\napi_key_id\x18\x01 \x01(\t\"7\n\x13\x44\x65leteApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14\x44\x65leteApiKeyMetadata\x12\x12\n\napi_key_id\x18\x01 \x01(\t\"}\n\x1bListApiKeyOperationsRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1cListApiKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xea\x06\n\rApiKeyService\x12r\n\x04List\x12\'.yandex.cloud.iam.v1.ListApiKeysRequest\x1a(.yandex.cloud.iam.v1.ListApiKeysResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/iam/v1/apiKeys\x12o\n\x03Get\x12%.yandex.cloud.iam.v1.GetApiKeyRequest\x1a\x1b.yandex.cloud.iam.v1.ApiKey\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/iam/v1/apiKeys/{api_key_id}\x12y\n\x06\x43reate\x12(.yandex.cloud.iam.v1.CreateApiKeyRequest\x1a).yandex.cloud.iam.v1.CreateApiKeyResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/iam/v1/apiKeys:\x01*\x12\xa0\x01\n\x06Update\x12(.yandex.cloud.iam.v1.UpdateApiKeyRequest\x1a!.yandex.cloud.operation.Operation\"I\x82\xd3\xe4\x93\x02!2\x1c/iam/v1/apiKeys/{api_key_id}:\x01*\xb2\xd2*\x1e\n\x14UpdateApiKeyMetadata\x12\x06\x41piKey\x12\xac\x01\n\x06\x44\x65lete\x12(.yandex.cloud.iam.v1.DeleteApiKeyRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02\x1e*\x1c/iam/v1/apiKeys/{api_key_id}\xb2\xd2*-\n\x14\x44\x65leteApiKeyMetadata\x12\x15google.protobuf.Empty\x12\xa6\x01\n\x0eListOperations\x12\x30.yandex.cloud.iam.v1.ListApiKeyOperationsRequest\x1a\x31.yandex.cloud.iam.v1.ListApiKeyOperationsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/iam/v1/apiKeys/{api_key_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETAPIKEYREQUEST = _descriptor.Descriptor(
  name='GetApiKeyRequest',
  full_name='yandex.cloud.iam.v1.GetApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.GetApiKeyRequest.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=322,
)


_LISTAPIKEYSREQUEST = _descriptor.Descriptor(
  name='ListApiKeysRequest',
  full_name='yandex.cloud.iam.v1.ListApiKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.ListApiKeysRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListApiKeysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListApiKeysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=444,
)


_LISTAPIKEYSRESPONSE = _descriptor.Descriptor(
  name='ListApiKeysResponse',
  full_name='yandex.cloud.iam.v1.ListApiKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_keys', full_name='yandex.cloud.iam.v1.ListApiKeysResponse.api_keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListApiKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=539,
)


_CREATEAPIKEYREQUEST = _descriptor.Descriptor(
  name='CreateApiKeyRequest',
  full_name='yandex.cloud.iam.v1.CreateApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.CreateApiKeyRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.CreateApiKeyRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=632,
)


_CREATEAPIKEYRESPONSE = _descriptor.Descriptor(
  name='CreateApiKeyResponse',
  full_name='yandex.cloud.iam.v1.CreateApiKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key', full_name='yandex.cloud.iam.v1.CreateApiKeyResponse.api_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='yandex.cloud.iam.v1.CreateApiKeyResponse.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=718,
)


_UPDATEAPIKEYREQUEST = _descriptor.Descriptor(
  name='UpdateApiKeyRequest',
  full_name='yandex.cloud.iam.v1.UpdateApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.UpdateApiKeyRequest.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.iam.v1.UpdateApiKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.UpdateApiKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=857,
)


_UPDATEAPIKEYMETADATA = _descriptor.Descriptor(
  name='UpdateApiKeyMetadata',
  full_name='yandex.cloud.iam.v1.UpdateApiKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.UpdateApiKeyMetadata.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=901,
)


_DELETEAPIKEYREQUEST = _descriptor.Descriptor(
  name='DeleteApiKeyRequest',
  full_name='yandex.cloud.iam.v1.DeleteApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.DeleteApiKeyRequest.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=958,
)


_DELETEAPIKEYMETADATA = _descriptor.Descriptor(
  name='DeleteApiKeyMetadata',
  full_name='yandex.cloud.iam.v1.DeleteApiKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.DeleteApiKeyMetadata.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1002,
)


_LISTAPIKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListApiKeyOperationsRequest',
  full_name='yandex.cloud.iam.v1.ListApiKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key_id', full_name='yandex.cloud.iam.v1.ListApiKeyOperationsRequest.api_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListApiKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListApiKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1129,
)


_LISTAPIKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListApiKeyOperationsResponse',
  full_name='yandex.cloud.iam.v1.ListApiKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.iam.v1.ListApiKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListApiKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1241,
)

_LISTAPIKEYSRESPONSE.fields_by_name['api_keys'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2._APIKEY
_CREATEAPIKEYRESPONSE.fields_by_name['api_key'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2._APIKEY
_UPDATEAPIKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTAPIKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetApiKeyRequest'] = _GETAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['ListApiKeysRequest'] = _LISTAPIKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListApiKeysResponse'] = _LISTAPIKEYSRESPONSE
DESCRIPTOR.message_types_by_name['CreateApiKeyRequest'] = _CREATEAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateApiKeyResponse'] = _CREATEAPIKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateApiKeyRequest'] = _UPDATEAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateApiKeyMetadata'] = _UPDATEAPIKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteApiKeyRequest'] = _DELETEAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteApiKeyMetadata'] = _DELETEAPIKEYMETADATA
DESCRIPTOR.message_types_by_name['ListApiKeyOperationsRequest'] = _LISTAPIKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListApiKeyOperationsResponse'] = _LISTAPIKEYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetApiKeyRequest = _reflection.GeneratedProtocolMessageType('GetApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPIKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.GetApiKeyRequest)
  })
_sym_db.RegisterMessage(GetApiKeyRequest)

ListApiKeysRequest = _reflection.GeneratedProtocolMessageType('ListApiKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListApiKeysRequest)
  })
_sym_db.RegisterMessage(ListApiKeysRequest)

ListApiKeysResponse = _reflection.GeneratedProtocolMessageType('ListApiKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListApiKeysResponse)
  })
_sym_db.RegisterMessage(ListApiKeysResponse)

CreateApiKeyRequest = _reflection.GeneratedProtocolMessageType('CreateApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateApiKeyRequest)
  })
_sym_db.RegisterMessage(CreateApiKeyRequest)

CreateApiKeyResponse = _reflection.GeneratedProtocolMessageType('CreateApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateApiKeyResponse)
  })
_sym_db.RegisterMessage(CreateApiKeyResponse)

UpdateApiKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPIKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateApiKeyRequest)
  })
_sym_db.RegisterMessage(UpdateApiKeyRequest)

UpdateApiKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateApiKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPIKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateApiKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateApiKeyMetadata)

DeleteApiKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPIKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteApiKeyRequest)
  })
_sym_db.RegisterMessage(DeleteApiKeyRequest)

DeleteApiKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteApiKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPIKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteApiKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteApiKeyMetadata)

ListApiKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListApiKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListApiKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListApiKeyOperationsRequest)

ListApiKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListApiKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.api_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListApiKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListApiKeyOperationsResponse)


DESCRIPTOR._options = None
_GETAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
_LISTAPIKEYSREQUEST.fields_by_name['service_account_id']._options = None
_LISTAPIKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTAPIKEYSREQUEST.fields_by_name['page_token']._options = None
_CREATEAPIKEYREQUEST.fields_by_name['service_account_id']._options = None
_CREATEAPIKEYREQUEST.fields_by_name['description']._options = None
_UPDATEAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
_UPDATEAPIKEYREQUEST.fields_by_name['description']._options = None
_DELETEAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
_LISTAPIKEYOPERATIONSREQUEST.fields_by_name['api_key_id']._options = None
_LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_APIKEYSERVICE = _descriptor.ServiceDescriptor(
  name='ApiKeyService',
  full_name='yandex.cloud.iam.v1.ApiKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1244,
  serialized_end=2118,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.iam.v1.ApiKeyService.List',
    index=0,
    containing_service=None,
    input_type=_LISTAPIKEYSREQUEST,
    output_type=_LISTAPIKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/iam/v1/apiKeys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.iam.v1.ApiKeyService.Get',
    index=1,
    containing_service=None,
    input_type=_GETAPIKEYREQUEST,
    output_type=yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2._APIKEY,
    serialized_options=b'\202\323\344\223\002\036\022\034/iam/v1/apiKeys/{api_key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iam.v1.ApiKeyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEAPIKEYREQUEST,
    output_type=_CREATEAPIKEYRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/iam/v1/apiKeys:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.iam.v1.ApiKeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEAPIKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!2\034/iam/v1/apiKeys/{api_key_id}:\001*\262\322*\036\n\024UpdateApiKeyMetadata\022\006ApiKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.iam.v1.ApiKeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEAPIKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036*\034/iam/v1/apiKeys/{api_key_id}\262\322*-\n\024DeleteApiKeyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.iam.v1.ApiKeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTAPIKEYOPERATIONSREQUEST,
    output_type=_LISTAPIKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/iam/v1/apiKeys/{api_key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APIKEYSERVICE)

DESCRIPTOR.services_by_name['ApiKeyService'] = _APIKEYSERVICE

# @@protoc_insertion_point(module_scope)
